@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: concurrent-output
 version: 1.7.4
-id: concurrent-output-1.7.4-f9691346a71b8edc8569215c754d5bdc
-key: concu_L0G7AjnHel5Iot3N2TvIME
+id: concurrent-output-1.7.4-c9a050c65927cdc42dfa69f5624b309c
+key: concu_JtjeuR7JnbWDY5pb1YQhGv
 license: BSD2
 copyright: 2015 Joey Hess, 2009 Joachim Breitner
 maintainer: Joey Hess <id@joeyh.name>
@@ -29,7 +29,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/concurrent-output-1.7.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/concurrent-output-1.7.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/concurrent-output-1.7.4
-hs-libraries: HSconcurrent-output-1.7.4-L0G7AjnHel5Iot3N2TvIME
+hs-libraries: HSconcurrent-output-1.7.4-JtjeuR7JnbWDY5pb1YQhGv
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
@@ -39,7 +39,7 @@ depends:
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
     terminal-size-0.3.2.1-bd07744e217c7dfc314ba4633ffee89d
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
 haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
